RunInit <- function () {
	library(gplots)
	library(pixmap)
	RunData<<-read.table(file="run_data.csv",header=TRUE,sep=",",na.strings="NA")
	RunData$P_filter = (512-ANA0)*4.8828
    attach(RunData)
##	Events<<-read.table(file="events.csv",header=TRUE,sep=",")
}

RunPlot <- function() {
	## Plotting Variables
	n<-16
	#full plot
	#plot_start<-0
	#plot_end<-9900
    
    # 30 second tests
    plot_start<-5100
	plot_end<-6600
	axis_text_size <-16
	data_text_size <-12
	##colors<-rainbow(n, s = 1, v = 1, start = 0, end = max(1,n - 1)/n,gamma = 1, alpha = 1)
	##colors<-c(hsv(.1,.5.,.5),hsv(.2,.5.,.5),hsv(.3,.5.,.5),hsv(.4,.5.,.5))
	##colors<-c("black","red1","red2","grey","orange","grey1","grey2","grey3","grey4","grey5","grey6","grey7","steelblue")
	colors<-c("blue","yellow","orange","red","#66FF33","#FFFF0066","#FFCC0066","#FF990066","#FF660066","#FF330066","#FF000066","#FF33FF","#990000")
	## Setup
	par(mfrow=c(1,1)) ## plot to 3 rows
	## Plot Temps
    par(xaxt="n") ## don't plot x-axis
    par(ps=axis_text_size)
    par(mar=c(0,5,1,1)) ## set plot margins
    par(fig=c(0,1,.6,1),new=FALSE)
    plot(T_air_in~Abs_Time,type="l",col=colors[1],xlim=c(plot_start,plot_end),ylim=c(0,1000),ylab="Temperature [°C]")
    grid(NULL, NULL, lwd = 1)
	lines(T_bred~Abs_Time,col=colors[2])
	lines(T_tred~Abs_Time,col=colors[3])
	lines(T_comb~Abs_Time,col=colors[4])
	#lines(T_1in~Abs_Time,col=colors[5])
	#lines(T_2in~Abs_Time,col=colors[6])
	#lines(T_3in~Abs_Time,col=colors[7])
	#lines(T_4in~Abs_Time,col=colors[8])
	#lines(T_6in~Abs_Time,col=colors[9])
	#lines(T_8in~Abs_Time,col=colors[10])
	lines(T_gas_out~Abs_Time,col=colors[11])
##	lines(T_flare~Abs_Time,col=colors[12])
	
	smartlegend(x="left",y="top", inset = 0,
            c("T_air_in","T_bred", "T_tred","T_comb","T_1in","T_2in","T_3in","T_4in","T_6in","T_8in","T_gas_out","T_flare"),
            fill = colors[1:13])    
	
	#Pressures
	data<-list(d1=P_reactor,d2=P_comb,d3=P_filter) ## attemping to refactor the plot routines to be more understandable, plotting should move into a function
	names<-c("Reactor","Comb","Filter")
	colors<-c("red","blue","green")
    par(fig=c(0,1,.4,.6),new=TRUE)
    plot((data$d1*-0.0040146)~Abs_Time,type="l",col=colors[1],xlim=c(plot_start,plot_end),ylim=c(-.5,11),ylab="Vacuum [inH2O]")
    lines((data$d2*-0.0040146)~Abs_Time,type="l",col=colors[2])
    lines((data$d3*0.0040146)~Abs_Time,type="l",col=colors[3])
    grid(NULL, NULL, lwd = 1)
    smartlegend(x="left",y="top", inset = 0,
            names,
            fill = colors)
	#CO2
	par(fig=c(0,1,.3,.4),new=TRUE)
	plot(CO2~Abs_Time,type="l",xlim=c(plot_start,plot_end),ylab="CO2")
	
    #Flow
	par(new=TRUE)
	par(mar=c(5,5,1,1))
    par(xaxt="n")
    par(fig=c(0,1,0,.3))
	plot(Q_air_in~Abs_Time,type="l",xlim=c(plot_start,plot_end),ylim=c(0,50),ylab="Flow [m3/hr]",xlab="Time [minutes]")
	lines(Q_gas_out~Abs_Time,type="l",col="blue")
	grid(NULL, NULL, lwd = 1)
	smartlegend(x="left",y="top", inset = 0, c("Air In","Gas Out"), fill = c("black","blue"))
    ## draw x-axis
    par(xaxt="s")
	par(ps=axis_text_size)
	axis(1,at=seq(from=plot_start,to=plot_end,by=60*10),labels=seq(from=(plot_start/60),to=(plot_end/60),by=10)) ## plot x-axis in minutes
	
}

HeatMap <- function() {
	## Temperatures should get mapped to better color ranges.
	par(mfrow=c(1,1))
	image(matrix(data=c(T_flare,T_gas_out,T_bred,T_tred,T_air_in,T_comb,T_1in,T_2in,T_3in,T_4in,T_6in,T_8in),ncol=12),col=rainbow(1000, start=.7, end=.1))
	text(c(0.03,0.03,0.03,0.03,0.03,0.03,0.03,0.03),c(0/11,1/11,2/11,3/11,4/11,5/11,6/11,7/11,8/11,9/11,10/11,11/11),c("T_flare","T_gas_out","T_bred","T_tred","T_air_in","T_comb","T_1in","T_2in","T_3in","T_4in","T_6in","T_8in"))
}

ContourMap <- function(plot_start=0,plot_end=8000) {
	cont<- c(25,100,200,300,400,500,600,700,800,900,1000,1100,1200)
	cont_col<-c("#FFFFFF","#AA887F","#BB7866","#CC684C","#DD5833","#EE4819","#ff3800","#ff6500","#ff7e00","#ff932c","#ffa54f","#ffb46b","#ffc184")
par(xaxt="n") ## don't plot x-axis
filled.contour(x=seq(plot_start,plot_end),y=c(-8.5,-2.5,0,1,2,3,4,6,8),z=matrix(data=c(T_bred[plot_start:plot_end],T_tred[plot_start:plot_end],T_comb[plot_start:plot_end],T_1in[plot_start:plot_end],T_2in[plot_start:plot_end],T_3in[plot_start:plot_end],T_4in[plot_start:plot_end],T_6in[plot_start:plot_end],T_8in[plot_start:plot_end]),ncol=9,nrow=(plot_end-plot_start+1)),levels=cont,col=cont_col,xlab="Time (No Interpolation) [min]",ylab="Position [in]",key.title="T [°C]")

	abline(h=0)
	abline(h=-2.5)
	abline(h=-8.5)
	text(x=plot_start,y=0.25,labels="Combustion",pos=4)
	text(x=plot_start,y=-2.25,labels="Top Reduction",pos=4)
	text(x=plot_start,y=-8.25,labels="Bottom Reduction",pos=4)
	par(xaxt="s") ## plot x-axis
	axis(1,at=seq(from=plot_start,to=plot_end,by=60*10),labels=seq(from=(plot_start/60),to=(plot_end/60),by=10)) ## plot x-axis in minutes
}

RunBoxPlots <- function() {
	states <- States()
	n_states <- 6
	par(xaxt="n")
	boxplot(T_comb ~ states$cluster,outline=FALSE,col=c(1,2,3,4,5,6),boxwex=0.2,at=seq(from=0.5,to=6,length.out=6),varwidth=TRUE)
	par(yaxt="n")
	boxplot(T_tred ~ states$cluster,outline=FALSE,col=c(1,2,3,4,5,6),boxwex=0.2,at=seq(from=0.75,to=6.25,length.out=6), varwidth=TRUE,add=TRUE)
	boxplot(T_bred ~ states$cluster,outline=FALSE,col=c(1,2,3,4,5,6),boxwex=0.2,at=seq(from=1,to=6.5,length.out=6), varwidth=TRUE,add=TRUE)
	par(xaxt="s")
	par(yaxt="s")
	par(las=2) ##axis rotation
	axis(1,at=seq(from=.5,to=7,by=1.1),labels=c("T_comb","T_comb","T_comb","T_comb","T_comb","T_comb")) ## plot x-axis
	axis(1,at=seq(from=.75,to=7.25,by=1.1),labels=c("T_tred","T_tred","T_tred","T_tred","T_tred","T_tred")) ## plot x-axis
	axis(1,at=seq(from=1,to=7.5,by=1.1),labels=c("T_bred","T_bred","T_bred","T_bred","T_bred","T_bred")) ## plot x-axis
}     

States <- function() {
	##return(kmeans(data.frame(T_comb,T_bred,T_tred,P_reactor),6))
	return(kmeans(data.frame(P_reactor),6))
}

CombineRawData <- function() {
	files<-list.files("raw_data")
	for (file in files) {
		text<-substr(file, 5, nchar(file))
	    text<-substr(text,0,nchar(text)-4)
		chunks<-strsplit(text," ")
		date<-chunks[[1]][1]
		time<-chunks[[1]][2]
		year<-substr(date,0,4)
		month<-substr(date,5,6)
		day<-substr(date,7,8)
		hour<-substr(time,1,2)
		minute<-substr(time,3,4)
		second<-substr(time,5,6)
		seconds<-as.numeric(day)*24*60*60
		seconds<-seconds+as.numeric(hour)*60*60
		seconds<-seconds+as.numeric(minute)*60
		seconds<-seconds+as.numeric(second)
		print(seconds)
	    data<-read.table(file=file,header=TRUE,sep=",",na.strings="",comment.char = "#", skip=1)
	    for (line in data) {
	    	time <- seconds+line[0]
	    	
	    }
	    
	}
}
          
PyrolysisLM <- function() {
	start <- 0
	end <- 10000
	for(t in start:end) {
		model<-lm(c(T_1in[t],T_2in[t],T_3in[t],T_4in[t],T_6in[t],T_8in[t])~c(1,2,3,4,6,8))
		intercept <- as.numeric(m$coefficients[1])
		slope <- as.numeric(m$coefficients[2])
	}
}